pub enum MismatchSide {
Target,
Base,
Result,
}Expand description
Which declared value or checksum failed to verify while applying a delta.
Variants
Target
The declared target length did not match the reconstruction.
Base
The base checksum did not match.
Result
The reconstructed target checksum did not match.